Documentation
¶
Overview ¶
Package module provides the logic for running each section of the i3/sway bar.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Battery ¶
type Battery struct {
// contains filtered or unexported fields
}
Battery is a module that prints the capacity of batteries. Only works on Linux.
type Datetime ¶
type Datetime struct {
// For example: Local, UTC, Europe/Zurich, etc.
Timezones []string `mapstructure:"timezones"`
// Whether to show all timezones at once. If false, the timezones can be
// toggled with a middle click.
ShowAllTimezones bool `mapstructure:"show_all_timezones"`
// contains filtered or unexported fields
}
Datetime is a module for printing the date and time.
type Memory ¶
type Memory struct {
// contains filtered or unexported fields
}
Memory provides information on RAM and swap usage for the system. Only works on Linux.
Click to show internal directories.
Click to hide internal directories.